@@ -36,7 +36,7 @@ class DefaultHandler(web.RequestHandler):
     def write_error(self, status_code, exc_info=None):
         if status_code == 404:
             body = read_text('tutorial_server.static', '404.html')
-            body = body.replace('${baseurl}', f'{options.basepath}/')
+            body = body.replace('${baseurl}', f'{options.basepath}')
             self.write(body)
         elif status_code == 503:
             self.write(read_text('tutorial_server.static', '503.html'))
@@ -51,14 +51,14 @@ class RootHandler(web.RequestHandler):
 
     def get(self):
         if content_ready():
-            self.redirect(f'{options.basepath}/{config.get("app", "default")}/')
+            self.redirect(f'{options.basepath}{config.get("app", "default")}/')
         else:
             self.send_error(status_code=503)
 
     def write_error(self, status_code, exc_info=None):
         if status_code == 404:
             body = read_text('tutorial_server.static', '404.html')
-            body = body.replace('${baseurl}', f'{options.basepath}/')
+            body = body.replace('${baseurl}', f'{options.basepath}')
             self.write(body)
         elif status_code == 503:
             self.write(read_text('tutorial_server.static', '503.html'))
@@ -95,11 +95,14 @@ class DownloadHandler(RootHandler):
         if content_ready():
             buffer = BytesIO()
             with ZipFile(buffer, mode='w') as zip_file:
-                homepath = config.get('app', 'home')
-                for basepath, _, filenames in os.walk(homepath):
-                    for filename in filenames:
-                        filepath = os.path.join(basepath, filename)
-                        zip_file.write(filepath, f'{config.get("app", "name")}/{filepath[len(homepath) + 1:]}')
+                for part in [p.strip() for x in config.get('app', 'parts').split(',') for p in x.split('\n')]:
+                    if config.has_section(f'app:{part}'):
+                        part_path = os.path.join(config.get('app', 'home'), config.get(f'app:{part}', 'target'))
+                        home_path = config.get('app', 'home')
+                        for basepath, _, filenames in os.walk(part_path):
+                            for filename in filenames:
+                                filepath = os.path.join(basepath, filename)
+                                zip_file.write(filepath, f'{config.get("app", "name")}/{filepath[len(home_path) + 1:]}')
             self.set_header('Content-Type', 'application/zip')
             self.set_header('Content-Disposition', f'attachment; filename={config.get("app", "name")}.zip')
             self.write(buffer.getvalue())
